==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/lt_LT.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Pirmojo paleidimo vediklis",
    "Add your profile information! For example your email is needed to reset your password." : "Pridėkite savo profilio informaciją! Pavyzdžiui, jūsų el. paštas yra reikalingas, norint atstatyti savo slaptažodį.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Pridėkite savo profilio informaciją! Nustatykite profilio paveikslą ir visą vardą, kad lengviau būtumėte atpažinti tarp visų ypatybių.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Pridėkite savo profilio informaciją! Nustatykite visą vardą, kad lengviau būtumėte atpažinti tarp visų ypatybių.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Pridėkite savo profilio informaciją! Nustatykite profilio paveikslą, kad lengviau būtumėte atpažinti tarp visų ypatybių.",
    "About" : "Apie",
    "A welcome and introduction wizard for Nextcloud" : "Pasisveikinimo ir pristatymo vediklis, skirtas Nextcloud",
    "Previous" : "Ankstesnis",
    "Next" : "Kitas",
    "Close" : "Užverti",
    "Start using Nextcloud" : "Pradėti naudotis Nextcloud",
    "Extend your cloud" : "Išplėskite savo debesiją",
    "Stay in sync" : "Išlaikykite viską sinchronizuotai",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud suteikia jums prieigą prie failų, nesvarbu, kur bebūtumėte.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Mūsų lengvi naudoti darbalaukio ir mobilieji klientai yra prieinami pagrindinėms platformoms visiškai nemokamai!",
    "Get the apps to sync your files" : "Norėdami sinchronizuoti savo failus, atsisiųskite programėles",
    "Desktop client" : "Darbalaukio klientas",
    "Android app" : "Android programėlė",
    "iOS app" : "iOS programėlė",
    "Connect your desktop apps to %s" : "Prijunkite savo kompiuterio programas prie %s",
    "Connect your calendar" : "Prijunkite savo kalendorių",
    "Connect your contacts" : "Prijunkite savo kontaktus",
    "Access files via WebDAV" : "Pasiekite failus per WebDAV",
    "Get help" : "Gaukite pagalbos",
    "Get more information" : "Gaukite daugiau informacijos",
    "The Nextcloud documentation for home users:" : "Nextcloud dokumentacija namų naudotojams:",
    "User manual" : "Naudotojo vadovas",
    "Admin manual" : "Administratoriaus vadovas",
    "Developer manual" : "Kūrėjo vadovas",
    "You can also ask for help in our community support channels:" : "Taip pat galite prašyti pagalbos mūsų bendruomenės palaikymo kanaluose:",
    "the Nextcloud forums" : "Nextcloud forumuose",
    "the Nextcloud IRC chat channel on freenode.net" : "Nextcloud IRC pokalbių kanale, freenode.net serveryje",
    "Start contributing" : "Pradėkite talkinti",
    "Become part of the Community" : "Tapkite bendruomenės dalimi",
    "A safe home for all your data" : "Saugūs namai visiems jūsų duomenims",
    "Host your data and files where you decide" : "Saugokite savo duomenis ir failus ten, kur nuspręsite",
    "Open Standards and Interoperability" : "Atviri standartai ir funkcinis suderinamumas",
    "100%% Open Source & community-focused" : "100%% atvirojo kodo ir sutelkta į bendruomenę",
    "Learn more about %s" : "Sužinokite daugiau apie %s",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s suteikia jums prieigą prie jūsų failų visur, kur bebūtumėte. Mūsų lengvi naudoti darbalaukio ir mobilieji klientai yra prieinami pagrindinėms platformoms visiškai nemokamai.",
    "Connect other apps to %s" : "Prijunkite kitas programas prie %s",
    "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Be sinchronizavimo klientų, prie %s taip pat galite prijungti bet kokią programinę įrangą, kuri palaiko WebDAV/CalDAV/CardDAV protokolus.",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Jeigu norite palaikyti projektą {contributeopen}prisijunkite prie jo plėtojimo{linkclose} arba {contributeopen}skleiskite apie jį žinią{linkclose}!",
    "Show First Run Wizard again" : "Rodyti pirmojo paleidimo vediklį dar kartą",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Gaukite prieigą ir bendrinkite savo failus, kalendorius, kontaktus, paštą ir daug daugiau iš bet kurio įrenginio, savo sąlygomis",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Daugiau informacijos yra prieinama <a target=\"_blank\" href=\"%s\">dokumentacijoje</a> ir mūsų <a target=\"_blank\" href=\"%s\">svetainėje</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Jeigu jums patinka Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud yra puiki atviroji programinė įranga, kuri yra skirta failų sinchronizavimui ir bendrinimui. Tu gali ją lengvai atsisiųsti iš https://nextcloud.com\"> rekomenduokite ją savo draugams</a> ir <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">talkinkite jai</a>!"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/lt_LT.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Pirmojo paleidimo vediklis",
    "Add your profile information! For example your email is needed to reset your password." : "Pridėkite savo profilio informaciją! Pavyzdžiui, jūsų el. paštas yra reikalingas, norint atstatyti savo slaptažodį.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Pridėkite savo profilio informaciją! Nustatykite profilio paveikslą ir visą vardą, kad lengviau būtumėte atpažinti tarp visų ypatybių.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Pridėkite savo profilio informaciją! Nustatykite visą vardą, kad lengviau būtumėte atpažinti tarp visų ypatybių.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Pridėkite savo profilio informaciją! Nustatykite profilio paveikslą, kad lengviau būtumėte atpažinti tarp visų ypatybių.",
    "About" : "Apie",
    "A welcome and introduction wizard for Nextcloud" : "Pasisveikinimo ir pristatymo vediklis, skirtas Nextcloud",
    "Previous" : "Ankstesnis",
    "Next" : "Kitas",
    "Close" : "Užverti",
    "Start using Nextcloud" : "Pradėti naudotis Nextcloud",
    "Extend your cloud" : "Išplėskite savo debesiją",
    "Stay in sync" : "Išlaikykite viską sinchronizuotai",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud suteikia jums prieigą prie failų, nesvarbu, kur bebūtumėte.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Mūsų lengvi naudoti darbalaukio ir mobilieji klientai yra prieinami pagrindinėms platformoms visiškai nemokamai!",
    "Get the apps to sync your files" : "Norėdami sinchronizuoti savo failus, atsisiųskite programėles",
    "Desktop client" : "Darbalaukio klientas",
    "Android app" : "Android programėlė",
    "iOS app" : "iOS programėlė",
    "Connect your desktop apps to %s" : "Prijunkite savo kompiuterio programas prie %s",
    "Connect your calendar" : "Prijunkite savo kalendorių",
    "Connect your contacts" : "Prijunkite savo adresatus",
    "Access files via WebDAV" : "Pasiekite failus per WebDAV",
    "Get help" : "Gaukite pagalbos",
    "Get more information" : "Gaukite daugiau informacijos",
    "The Nextcloud documentation for home users:" : "Nextcloud dokumentacija namų naudotojams:",
    "User manual" : "Naudotojo vadovas",
    "Admin manual" : "Administratoriaus vadovas",
    "Developer manual" : "Kūrėjo vadovas",
    "You can also ask for help in our community support channels:" : "Taip pat galite prašyti pagalbos mūsų bendruomenės palaikymo kanaluose:",
    "the Nextcloud forums" : "Nextcloud forumuose",
    "the Nextcloud IRC chat channel on freenode.net" : "Nextcloud IRC pokalbių kanale, freenode.net serveryje",
    "Start contributing" : "Pradėkite talkinti",
    "Become part of the Community" : "Tapkite bendruomenės dalimi",
    "A safe home for all your data" : "Saugūs namai visiems jūsų duomenims",
    "Host your data and files where you decide" : "Saugokite savo duomenis ir failus ten, kur nuspręsite",
    "Open Standards and Interoperability" : "Atviri standartai ir funkcinis suderinamumas",
    "100%% Open Source & community-focused" : "100%% atvirojo kodo ir sutelkta į bendruomenę",
    "Learn more about %s" : "Sužinokite daugiau apie %s",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s suteikia jums prieigą prie jūsų failų visur, kur bebūtumėte. Mūsų lengvi naudoti darbalaukio ir mobilieji klientai yra prieinami pagrindinėms platformoms visiškai nemokamai.",
    "Connect other apps to %s" : "Prijunkite kitas programas prie %s",
    "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Be sinchronizavimo klientų, prie %s taip pat galite prijungti bet kokią programinę įrangą, kuri palaiko WebDAV/CalDAV/CardDAV protokolus.",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Jeigu norite palaikyti projektą {contributeopen}prisijunkite prie jo plėtojimo{linkclose} arba {contributeopen}skleiskite apie jį žinią{linkclose}!",
    "Show First Run Wizard again" : "Rodyti pirmojo paleidimo vediklį dar kartą",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Gaukite prieigą ir bendrinkite savo failus, kalendorius, adresatus, paštą ir daug daugiau iš bet kurio įrenginio, savo sąlygomis",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Daugiau informacijos yra prieinama <a target=\"_blank\" href=\"%s\">dokumentacijoje</a> ir mūsų <a target=\"_blank\" href=\"%s\">svetainėje</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Jeigu jums patinka Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud yra puiki atviroji programinė įranga, kuri yra skirta failų sinchronizavimui ir bendrinimui. Tu gali ją lengvai atsisiųsti iš https://nextcloud.com\"> rekomenduokite ją savo draugams</a> ir <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">talkinkite jai</a>!"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
